@extends('manual.base')

@section('manual-title', 'Training proposals stage')

@section('manual-content')
    <div class="row">
        <p class="lead">
            Reviewing the training proposals from novelty detection.
        </p>
        <p>
            When one of your MAIA jobs proceeds from <a href="{{route('manual-tutorials', ['maia', 'novelty-detection'])}}">novelty detection</a> to the training proposals stage, you will get a notification from BIIGLE. In this stage, the MAIA job requires manual interaction from you before it can proceed to the next stage. This is done in two steps, the <a href="#selection-of-training-proposals">selection of training proposals</a> and the <a href="#refinement-of-training-proposals">refinement of training proposals</a>.
        </p>

        <h3><a name="selection-of-training-proposals"></a>Selection of training proposals</h3>

        <p>
            To begin the selection of training proposals, open the <button class="btn btn-default btn-xs"><i class="fas fa-plus-square"></i></button>&nbsp;select training proposals tab in the sidebar. This will load and display all training proposals that were generated by the novelty detection or from your existing annotations. For each training proposal an image thumbnail is shown in a regular grid.
        </p>

        <p class="text-center">
            <a href="{{asset('vendor/maia/images/select_tp_grid.jpg')}}"><img src="{{asset('vendor/maia/images/select_tp_grid.jpg')}}" width="75%"></a>
        </p>

        <p>
            Your task in this step is to review all training proposals and select each one that shows (part of) an interesting object or image region with a click on the thumbnail.
        </p>

        <p class="text-center">
            <img src="{{asset('vendor/maia/images/select_tp_1.jpg')}}" width="30%">
            <img src="{{asset('vendor/maia/images/select_tp_2.jpg')}}" width="30%">
            <img src="{{asset('vendor/maia/images/select_tp_3.jpg')}}" width="30%">
        </p>

        <p>
            The regular grid of image thumbnails is specifically designed for you to be able to review a large amount of training proposals very quickly. The following keyboard shortcuts are available to navigate the grid:
        </p>

        <table class="table">
            <thead>
                <tr>
                    <th>Key</th>
                    <th>Function</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td><kbd>A</kbd>, <kbd>Arrow left</kbd>, <kbd>Page up</kbd></td>
                    <td>Move up one page</td>
                </tr>
                <tr>
                    <td><kbd>D</kbd>, <kbd>Arrow right</kbd>, <kbd>Page down</kbd></td>
                    <td>Move down one page</td>
                </tr>
                <tr>
                    <td><kbd>W</kbd>, <kbd>Arrow up</kbd></td>
                    <td>Move up one row</td>
                </tr>
                <tr>
                    <td><kbd>S</kbd>, <kbd>Arrow down</kbd></td>
                    <td>Move down one row</td>
                </tr>
                <tr>
                    <td><kbd>Home</kbd></td>
                    <td>Move up to the first row</td>
                </tr>
                <tr>
                    <td><kbd>End</kbd></td>
                    <td>Move down to the last row</td>
                </tr>
            </tbody>
        </table>

        <p>
            We recommend you to use the keyboard shortcuts to move through the image grid page by page and the mouse to select the interesting training proposals. To quickly select multiple adjacent training proposals in the grid, select the first one and then hold the <kbd>Shift</kbd> key while selecting the last one. This will select all training proposals between the first and the last selected one.
        </p>

        <p>
            To facilitate bulk-selection of training proposals you can pin one training proposal as a reference by clicking on the <button class="btn btn-default btn-xs"><i class="fa fa-thumbtack"></i></button> button that appears when you hover the mouse over the thumbnail of the training proposal. The reference proposal will now be pinned to the top left of the image grid and the remaining proposals will be sorted by their visual similarity to the reference. This will often group similar objects together, which can then be bulk-selected. A reference can be un-pinned with another click on the button or a different training proposal can be pinned directly.
        </p>

        <div style="display: flex; justify-content: space-between; flex-wrap: nowrap;">
            <figure class="text-center">
                <a href="{{asset('vendor/maia/images/select_tp_sort_1.jpg')}}">
                    <img src="{{asset('vendor/maia/images/select_tp_sort_1.jpg')}}" width="95%">
                </a>
                <br>
                <caption>Default image grid</caption>
            </figure>
            <figure class="text-center">
                <a href="{{asset('vendor/maia/images/select_tp_sort_2.jpg')}}">
                    <img src="{{asset('vendor/maia/images/select_tp_sort_2.jpg')}}" width="95%">
                </a>
                <br>
                <caption>Sorted image grid</caption>
            </figure>
        </div>

        <p style="margin-top: 1em;">
            Please note that the quality of <a href="{{route('manual-tutorials', ['maia', 'annotation-candidates'])}}">annotation candidates</a> directly depends on the number of selected training proposals. In some cases a few hundred may be sufficient, in other cases many more might be required.
        </p>

        <p>
            When you are finished with the selection of interesting training proposals, continue to the refinement step.
        </p>

        <h3><a name="refinement-of-training-proposals"></a>Refinement of training proposals</h3>

        <p>
            To continue to the refinement of training proposals, click on the <button class="btn btn-default btn-xs">Proceed</button> button in the <button class="btn btn-default btn-xs"><i class="fas fa-plus-square"></i></button>&nbsp;select training proposals tab or directly open the <button class="btn btn-default btn-xs"><i class="fas fa-pen-square"></i></button>&nbsp;refine training proposals tab in the sidebar. This will display the training proposals directly on the images, similar to what you are used to from the annotation tool.
        </p>

        <p class="text-center">
            <a href="{{asset('vendor/maia/images/refine_tp_tool.jpg')}}"><img src="{{asset('vendor/maia/images/refine_tp_tool.jpg')}}" width="75%"></a>
        </p>

        <p>
            The refinement tool is designed to guide you quickly through all selected training proposals. The current selected training proposal is shown at the center and highlighted with a red circle. Other selected training proposals on the same image are displayed as blue circles. Other unselected training proposals are shown as semitransparent dashed circles.
        </p>

        <p>
            Your task in this step is to modify the position and size of the circle of each selected training proposal so it closely fits to the interesting object or image region. To move a circle, click and hold the center point of the circle with the mouse, then move the mouse so the circle is moved to the new position and finally release the mouse button. To resize a circle, click, hold and move the border of the circle, and release the mouse button once the circle has the correct size.
        </p>

        <p class="text-center">
            <img src="{{asset('vendor/maia/images/refine_tp_1.jpg')}}" width="24%">
            <img src="{{asset('vendor/maia/images/refine_tp_2.jpg')}}" width="24%">
            <img src="{{asset('vendor/maia/images/refine_tp_3.jpg')}}" width="24%">
            <img src="{{asset('vendor/maia/images/refine_tp_4.jpg')}}" width="24%">
        </p>

        <p>
            When you are finished with the refinement of one selected training proposal, continue to the next one with a click on the <i class="fas fa-step-forward"></i> button, or the <kbd>Space</kbd> or <kbd>Arrow right</kbd> shortcut keys. You can track your progress through all selected training proposals in the sidebar. It will tell you when have "seen" all selected training proposals.
        </p>

        <p>
            If you notice an interesting training proposal which has not been selected yet, you can select it directly in the refinement tool. First, click on the <button class="btn btn-default btn-xs"><i class="fas fa-plus"></i></button> button at the bottom and then click on the dashed circle of the unselected training proposal. If the currently highlighted training proposal was incorrectly selected as interesting you can unselect it by pressing <kbd>Delete</kbd> or the <button class="btn btn-default btn-xs"><i class="fas fa-minus"></i></button> button at the bottom.
        </p>

        <p class="text-center">
            <a href="{{asset('vendor/maia/images/refine_select_tp_1.jpg')}}"><img src="{{asset('vendor/maia/images/refine_select_tp_1.jpg')}}" width="40%"></a>
            <a href="{{asset('vendor/maia/images/refine_select_tp_2.jpg')}}"><img src="{{asset('vendor/maia/images/refine_select_tp_2.jpg')}}" width="40%"></a>
        </p>

        <p>
            You can finish the training proposals stage at any time with a click on the <button class="btn btn-default btn-xs">Submit training proposals</button> button in the <button class="btn btn-default btn-xs"><i class="fas fa-pen-square"></i></button>&nbsp;refine training proposals tab. Although we recommend you to review all training proposals in the select step and refine all training proposals in the refinement step, this is not a requirement for the submission of the selected training proposals. Training proposals can no longer be selected or modified once they have been submitted.
        </p>

        <p>
            When the training proposals have been submitted, the MAIA job automatically proceeds to the <a href="{{route('manual-tutorials', ['maia', 'object-detection'])}}">object detection</a> stage.
        </p>
       <h3>Further reading</h3>
        <ul>
            <li><a href="{{route('manual-tutorials', ['maia', 'about'])}}">An introduction to the Machine Learning Assisted Image Annotation method (MAIA).</a></li>
            <li><a href="{{route('manual-tutorials', ['maia', 'novelty-detection'])}}">Using novelty detection to obtain training data.</a></li>
            <li><a href="{{route('manual-tutorials', ['maia', 'existing-annotations'])}}">Using existing annotations to obtain training data.</a></li>
            <li><a href="{{route('manual-tutorials', ['maia', 'knowledge-transfer'])}}">Using knowledge transfer to obtain training data.</a></li>
            <li><a href="{{route('manual-tutorials', ['maia', 'object-detection'])}}">The automatic object detection.</a></li>
            <li><a href="{{route('manual-tutorials', ['maia', 'annotation-candidates'])}}">Reviewing the annotation candidates from object detection.</a></li>
        </ul>
    </div>
@endsection
